==> lego-web-0.0.55.tgz: package/src/stores/basic/menu.js <==
import Parse from 'parse'

const findActiveMenu = function (parent, children, activeMenuId) {
  for (let item of children) {
    item.parent = parent
    if (item.id === activeMenuId) return item
    if (item.children) {
      let activeMenu = findActiveMenu(item, item.children, activeMenuId)
      if (activeMenu) return activeMenu
    }
  }
}

export default {
  namespaced: true,
  state: {
    data: [],
    activeId: null,
    expand: null
  },
  mutations: {
    setMenuData(state, data) {
      state.data = data
    },
    setActive(state, menuId) {
      state.activeId = menuId
    },
    setExpand(state, item) {
      state.expand = item
    }
  },
  actions: {
    sync({ commit, state, rootState, dispatch }) {
      let Menu = Parse.Object.extend('LEGO_Menu')
      let menu = new Menu()
      menu.id = '0000000000'
      return menu.fetch().then(res => {
        commit('setMenuData', res.get('data'))
      })
    },
    fetch({ commit, state, rootState, dispatch }) {
      let Menu = Parse.Object.extend('LEGO_Menu')
      let menu = new Menu()
      menu.id = '0000000000'
      return menu.fetch().then(res => {
        return Promise.resolve(res.toJSON())
      })
    },
    save({ commit, state, rootState, dispatch }, data) {
      let Menu = Parse.Object.extend('LEGO_Menu')
      let menu = new Menu(data)
      menu.id = '0000000000'
      return menu.save().then(res => {
        return Promise.resolve(res.toJSON())
      })
    }
  },
  getters: {
    activeMenu: state => {
      let activeMenu = findActiveMenu(null, state.data, state.activeId)
      return activeMenu
    }
  }
}

==> lego-web-0.0.58.tgz: package/src/stores/basic/menu.js <==
import Parse from 'parse'

const findActiveMenu = function(parent, children, activeMenuId) {
  for (let item of children) {
    item.parent = parent
    if (item.id === activeMenuId) return item
    if (item.children) {
      let activeMenu = findActiveMenu(item, item.children, activeMenuId)
      if (activeMenu) return activeMenu
    }
  }
}

export default {
  namespaced: true,
  state: {
    data: [],
    activeId: null,
    expand: null
  },
  mutations: {
    setMenuData(state, data) {
      state.data = data
    },
    setActive(state, menuId) {
      state.activeId = menuId
    },
    setExpand(state, item) {
      state.expand = item
    }
  },
  actions: {
    sync({ commit, state, rootState, dispatch }) {
      let Menu = Parse.Object.extend('LEGO_Menu')
      let menu = new Menu()
      menu.id = '0000000000'
      return menu.fetch().then(res => {
        commit('setMenuData', [{ id: 'dashboard', url: '/', label: 'CMS_DASHBOARD' }].concat(res.get('data')))
      })
    },
    fetch({ commit, state, rootState, dispatch }) {
      let Menu = Parse.Object.extend('LEGO_Menu')
      let menu = new Menu()
      menu.id = '0000000000'
      return menu.fetch().then(res => {
        return Promise.resolve(res.toJSON())
      })
    },
    save({ commit, state, rootState, dispatch }, data) {
      let Menu = Parse.Object.extend('LEGO_Menu')
      let menu = new Menu(data)
      menu.id = '0000000000'
      return menu.save().then(res => {
        return Promise.resolve(res.toJSON())
      })
    }
  },
  getters: {
    activeMenu: state => {
      let activeMenu = findActiveMenu(null, state.data, state.activeId)
      return activeMenu
    }
  }
}
